@@ -3,7 +3,7 @@
 ################################################################################
 #' @keywords internal
 #' @author
-#' The Cancer Genome Atlas Analysis Network.
+#' The Cancer Genome Atlas Analysis Network
 #'
 #' @description
 #' For a given graph containing vertices, edges, and a signal associated with
@@ -52,34 +52,10 @@
 "_PACKAGE"
 #> [1] '_PACKAGE'
 
-################################################################################
-### Documentation for some 'toy' datasets
-################################################################################
-#' @title Toy 'igraph' objects.
-#'
-#' @description Small 'igraph' objects used for workflow demonstrations.
-#' All graphs include 'x', 'y', and 'name' vertex attributes.
-#'
-#' @format igraph
-#'
-#' @usage data(gtoy1)
-#'
-#' @source This package.
-#'
-#' @docType data
-#' @keywords gtoys
-#' @name gtoys
-#' @aliases gtoy1 gtoy2
-#' @return A pre-processed igraph object.
-#' @examples
-#' data(gtoy1)
-#' data(gtoy2)
-NULL
-
 ################################################################################
 ### Documentation for the 'gimage' dataset
 ################################################################################
-#' @title An image matrix.
+#' @title An image matrix
 #'
 #' @description An image matrix used for workflow demonstrations.
 #'
@@ -101,7 +77,7 @@ NULL
 ################################################################################
 ### Documentation for the 'PCv12_pruned_igraph' dataset
 ################################################################################
-#' @title A pruned and laid out igraph object from Pathway Commons V12.
+#' @title A pruned and laid out igraph object from Pathway Commons V12
 #'
 #' @description
 #' This igraph object was created from a 'sif' file available from 
@@ -143,7 +119,7 @@ NULL
 ################################################################################
 ### Documentation for the 'CGC_20211118' dataset
 ################################################################################
-#' @title COSMIC-CGC genes mapped to PathwaySpace images.
+#' @title COSMIC-CGC genes mapped to PathwaySpace images
 #'
 #' @description
 #' A data frame listing 'GeneSymbol' and 'Entrez' IDs from the
@@ -175,7 +151,7 @@ NULL
 ################################################################################
 ### Documentation for the 'Hallmarks_v2023_1_Hs_symbols' dataset
 ################################################################################
-#' @title A list with Hallmark gene sets (v2023.1).
+#' @title A list with Hallmark gene sets (v2023.1)
 #'
 #' @description
 #' A list with Human gene symbols from the MSigDB's Hallmark gene set 
@@ -207,7 +183,7 @@ NULL
 ################################################################################
 ### Colors for PathwaySpace
 ################################################################################
-#' @title A simple vector of colors for PathwaySpace images.
+#' @title A simple vector of colors for PathwaySpace images
 #'
 #' @param n Number of colors.
 #' @return A vector with hexadecimal color codes.
@@ -226,7 +202,7 @@ pspace.cols <- function(n=5) {
 ################################################################################
 ### Pathway space distance
 ################################################################################
-#' @title Calculate a pathway space distance between two vectors.
+#' @title Calculate a pathway space distance between two vectors
 #' 
 #' @param gdist A distance matrix computed by the igraph's \code{distances} 
 #' function. Rows and columns must be named with vertex labels as listed in
@@ -301,7 +277,7 @@ pathDistances <- function(gdist, from, to, nperm = 1000, verbose=TRUE){
 ################################################################################
 ### Plot pathway space distances
 ################################################################################
-#' @title Accessory function to plot pathway space distances.
+#' @title Accessory function to plot pathway space distances
 #' 
 #' @param pdist A list generated by the \code{\link{pathDistances}} function.
 #' @param z.transform A single logical value specifying to convert pathway 
@@ -323,20 +299,21 @@ pathDistances <- function(gdist, from, to, nperm = 1000, verbose=TRUE){
 #' plotPathDistances(res)
 #' 
 #' @importFrom stats density median density
-#' @importFrom ggplot2 geom_area ylab geom_segment geom_line theme_minimal
+#' @importFrom ggplot2 geom_area ylab geom_segment geom_line
+#' @importFrom ggplot2 xlab theme_minimal
 #' @aliases plotPathDistances
 #' @export
 #'
 plotPathDistances <- function(pdist, z.transform=FALSE){
   .validate.args("singleLogical", "z.transform", z.transform)
   if(z.transform){
-    gg <- .plot.pdist(pdist$z_score, xlab = "z-score")
+    gg <- .plot_pdist(pdist$z_score, xlab = "z-score")
   } else {
-    gg <- .plot.pdist(pdist$p_dist, xlab = "steps")
+    gg <- .plot_pdist(pdist$p_dist, xlab = "steps")
   }
   return(gg)
 }
-.plot.pdist <- function(pdist, xlab = "steps"){
+.plot_pdist <- function(pdist, xlab = "steps"){
   #---
   obs <- pdist$obs
   null <- pdist$null
